@@ -1,12 +1,14 @@
 """
 Utilities for handling geometry operations.
 """
-
+import copy
 from typing import List, Generator
 import math
 
 import mercantile
 import geojson
+import numpy as np
+import rasterio as rio
 import shapely
 import shapely.geometry
 from shapely.geometry import box
@@ -179,3 +181,61 @@ def count_vertices(geojson_geom: dict) -> int:
     assert total_vertices > 0, "no vertices were in geometry, check again!"
 
     return total_vertices
+
+
+def isclose(
+    transform1: rio.Affine,
+    transform2: rio.Affine,
+    rtol: float = 1e-05,
+    atol: float = 1e-08,
+) -> bool:
+    """
+    Operator to compare two Affine transformations. Returns true if equal under
+    tolerances.
+
+    The tolerance values are positive, typically very small numbers.
+    The relative difference (rtol * abs(b)) and the absolute difference
+    atol are added together to compare against the absolute difference
+    between a and b.
+
+    Arguments:
+        transform1: A rasterio transform object.
+        transform2: Another rasterio transform object.
+        rtol: Relative tolerance for comparison.
+        atol: Absolute tolerance for comparison.
+
+    Returns:
+        If the two transforms are equal within the given tolerances.
+
+    """
+    transform1_ar = np.array(transform1)
+    transform2_ar = np.array(transform2)
+    return np.allclose(transform1_ar, transform2_ar, rtol=rtol, atol=atol)
+
+
+def meta_is_equal(meta1: dict, meta2: dict, rtol=1e-05, atol=1e-08) -> bool:
+    """
+    Operator for comparing two metadata tags provided by a rasterio dataset.
+
+    Compares affine transformations with isclose method.
+
+    Arguments:
+        meta1: A meta object.
+        meta2: Another meta object.
+        rtol: Relative tolerance for comparison.
+        atol: Absolute tolerance for comparison.
+
+    Returns:
+        If the two meta objects are equal within the given tolerances.
+
+    """
+    meta1_transform = meta1.get("transform")
+    meta2_transform = meta2.get("transform")
+
+    meta1 = copy.deepcopy(meta1)
+    meta2 = copy.deepcopy(meta2)
+
+    del meta1["transform"]
+    del meta2["transform"]
+
+    return isclose(meta1_transform, meta2_transform, rtol, atol) and meta1 == meta2
